==> qtjambi-uic-6.5.1-sources.jar: io/qt/uic/ui4/DomPropertySpecifications.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomPropertySpecifications</p>
 */
public class DomPropertySpecifications extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomPropertySpecifications(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPropertySpecifications instance);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.uic.ui4.@Nullable DomStringPropertySpecification> elementStringpropertyspecification(){
        return elementStringpropertyspecification_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomStringPropertySpecification> elementStringpropertyspecification_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.uic.ui4.@Nullable DomPropertyToolTip> elementTooltip(){
        return elementTooltip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomPropertyToolTip> elementTooltip_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setElementStringpropertyspecification(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomStringPropertySpecification> a){
        setElementStringpropertyspecification_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementStringpropertyspecification_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomStringPropertySpecification> a);
    
    @QtUninvokable
    public final void setElementTooltip(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomPropertyToolTip> a){
        setElementTooltip_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementTooltip_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomPropertyToolTip> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomPropertySpecifications(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.2-sources.jar: io/qt/uic/ui4/DomPropertySpecifications.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomPropertySpecifications</code></p>
 */
public class DomPropertySpecifications extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomPropertySpecifications::<wbr>DomPropertySpecifications()</code></p>
     */
    public DomPropertySpecifications(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPropertySpecifications instance);
    
    /**
     * <p>See <code>DomPropertySpecifications::<wbr>elementStringpropertyspecification()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.uic.ui4.@Nullable DomStringPropertySpecification> elementStringpropertyspecification(){
        return elementStringpropertyspecification_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomStringPropertySpecification> elementStringpropertyspecification_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPropertySpecifications::<wbr>elementTooltip()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.uic.ui4.@Nullable DomPropertyToolTip> elementTooltip(){
        return elementTooltip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomPropertyToolTip> elementTooltip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPropertySpecifications::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomPropertySpecifications::<wbr>setElementStringpropertyspecification(QList&lt;DomStringPropertySpecification*&gt;)</code></p>
     */
    @QtUninvokable
    public final void setElementStringpropertyspecification(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomStringPropertySpecification> a){
        setElementStringpropertyspecification_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementStringpropertyspecification_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomStringPropertySpecification> a);
    
    /**
     * <p>See <code>DomPropertySpecifications::<wbr>setElementTooltip(QList&lt;DomPropertyToolTip*&gt;)</code></p>
     */
    @QtUninvokable
    public final void setElementTooltip(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomPropertyToolTip> a){
        setElementTooltip_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementTooltip_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomPropertyToolTip> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    /**
     * <p>See <code>DomPropertySpecifications::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomPropertySpecifications(QPrivateConstructor p) { super(p); } 
    
}
